searchData={"content_type":"text/markdown","items":[{"doc":"# FastPostmanCollection\n\nThis library helps you generate a Postman collection from your Phoenix router (`MyApp.Router`).\nYou can document your endpoints using `@doc` annotations for **params, body, form data**, and more.\nPipelines (plugs) can also be auto-scanned and added to the collection automatically.\n\nExample generated collection:\n\n![collection](assets/collection.png)\n\nThis library uses the official Postman schema: https://schema.postman.com/","ref":"FastPostmanCollection.html","title":"FastPostmanCollection","type":"module"},{"doc":"- [Installation](#installation)\n- [Description and Titles](#description-and-title-of-collection)\n- [Query Parameters](#params-in-your-collection)\n- [Body Parameters](#body-parameters)\n- [Form Data](#formdata-options)\n- [Authentication Tokens](#how-to-auto-scan-and-autoput-your-pipes-token)\n- [Organizing Folders](#organizing-folders-in-the-collection)\n- [Mix Commands](#mix-commands)\n- [Todo](#todo)\n- [Feedback](#you-like-the-idea)\n- [Changelog](#changelog)","ref":"FastPostmanCollection.html#module-table-of-contents","title":"Table of Contents - FastPostmanCollection","type":"module"},{"doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `fast_postman_collection` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:fast_postman_collection, \"~> 0.1.8\"}\n  ]\nend\n```\n\nConfigure fast_postman_collection\n\n- router -> your Phoenix router module *(required)*\n- pipe_tokens -> put in your auth bearer (`pipe_tokens`: a list of pipeline plugs (like `:admin_auth`) that should automatically add a Bearer token in the Postman request headers.)\n- variables -> variables to include in the Postman collection *(optional)*\n- file_path_collection -> path to save the generated collection *(optional)*\n\n```elixir\nconfig(:fast_postman_collection,\n  pipe_tokens: [:admin_auth, :user_auth],\n  name_collection: \"My collection\",\n  router: MyApp.Router,\n  variables: [\n    %{\n      key: \"host\",\n      value: \"http://localhost:4000\"\n    }\n  ]\n)\n```\n\nWhen you add router to your configuration, it will be able to generate a collection _using the command_ - `mix fs.get_collection`","ref":"FastPostmanCollection.html#module-installation","title":"Installation - FastPostmanCollection","type":"module"},{"doc":"![naming](assets/naming.png)\n\n```elixir\n@moduledoc \"\"\"\n# Post Controller\nThis will be used as the folder name in the generated Postman collection.\n\"\"\"\n\n@doc \"\"\"\n# Create Post\nThis will be used as the request title in the Postman collection.\n\nUse this endpoint to create a new post.\nAll content inside this doc block will be added to the request description in the collection.\n\"\"\"\n```\n\nIf you don't provide a `@doc` annotation, the default name will be taken from the module or function name.","ref":"FastPostmanCollection.html#module-description-and-title-of-collection","title":"Description and Title of collection - FastPostmanCollection","type":"module"},{"doc":"These parameters will be included in the URL as query strings.\nFor example, the generated URL might look like: ?limit=0&page=1\n\n```elixir\n@doc params: %{\n  limit: 0,\n  page: %{\n    key: \"page\",\n    value: 1,\n    description: \"Page number for pagination\"\n  }\n}\ndef index(conn, params) do\n  json(conn, params)\nend\n```\n\n![params](assets/params.png)","ref":"FastPostmanCollection.html#module-params-in-your-collection","title":"Params in Your Collection - FastPostmanCollection","type":"module"},{"doc":"These parameters will be included in the request body.\nBy default, the body is sent in JSON format.\n\nThis is how you define a request body in JSON format:\n\n```elixir\n@doc \"\"\"\n# Create post\n\"\"\"\n@doc body: %{\n        post: %{\n          title: \"\"\n        }\n      }\ndef create_post(conn, params) do\n  json(conn, params)\nend\n```\n\n![body](assets/body.png)","ref":"FastPostmanCollection.html#module-body-parameters","title":"Body Parameters - FastPostmanCollection","type":"module"},{"doc":"To send form data (e.g. file uploads):\n\n```elixir\n@doc mode: \"formdata\"\n@doc formdata: [\n        %{\n          key: \"image\",\n          value: nil,\n          type: \"file\"\n        }\n      ]\n```","ref":"FastPostmanCollection.html#module-formdata-options","title":"Formdata options - FastPostmanCollection","type":"module"},{"doc":"How to auto scan and autoput your pipe's token","ref":"FastPostmanCollection.html#module-how-to-auto-scan-and-apply-authentication-tokens","title":"How to Auto-Scan and Apply Authentication Tokens - FastPostmanCollection","type":"module"},{"doc":"router.ex\n\n```elixir\nscope \"/user\" do\n  pipe_through(:admin_auth)\n  get(\"/\", UserController, :index)\nend\n```\n\nconfig.exs\n\n```elixir\nconfig(:fast_postman_collection,\n  pipe_tokens: [:admin_auth, :user_auth]\n```\n\nAll tokens puts and scans from your pipelines\n\n![token](assets/token.png)","ref":"FastPostmanCollection.html#module-example","title":"Example - FastPostmanCollection","type":"module"},{"doc":"You can also automatically insert tokens into variables from a response:\n\n```elixir\n @doc auth_pre_request: %{is_enabled: true, from_resp_token: \"token\", variable_token: \"admin_variable\"}\n```","ref":"FastPostmanCollection.html#module-extract-token-from-response-automatically","title":"Extract Token from Response Automatically - FastPostmanCollection","type":"module"},{"doc":"You can use @moduledoc folder_path: \"Admin\" to place your module's requests inside a specific folder in the Postman collection.\n\nThe final folder structure will look like:\nAdmin / UserController\n\n#### Example\n\n```elixir\ndefmodule MyAppWeb.AdminUserController do\n  use MyAppWeb, :controller\n  @moduledoc folder_path: \"Admin\"\n  # this module puts to /admin/user controller\n  @moduledoc \"\"\"\n  # user controller\n  \"\"\"\n\nend\n```","ref":"FastPostmanCollection.html#module-organizing-folders-in-the-collection","title":"Organizing Folders in the Collection - FastPostmanCollection","type":"module"},{"doc":"- mix fs.get_collection: _This command generate in your directory file with collection_","ref":"FastPostmanCollection.html#module-mix-commands","title":"Mix commands - FastPostmanCollection","type":"module"},{"doc":"- [ ] filtering in mix fs.get_collection","ref":"FastPostmanCollection.html#module-todo","title":"Todo - FastPostmanCollection","type":"module"},{"doc":"If you like the idea of the library, write in this \"issue\" on github and I will add this functionality as soon as I have free time.","ref":"FastPostmanCollection.html#module-you-like-the-idea","title":"You like the idea? - FastPostmanCollection","type":"module"},{"doc":"- 0.1.8: Exclude null entries in Request Header, fix for full paragraph and update documentation for library\n- 0.1.7: Added support for including endpoint descriptions in Postman collections\n- 0.1.6: Previous version","ref":"FastPostmanCollection.html#module-changelog","title":"Changelog - FastPostmanCollection","type":"module"},{"doc":"","ref":"FastPostmanCollection.html#generate/1","title":"FastPostmanCollection.generate/1","type":"function"},{"doc":"","ref":"FastPostmanCollection.html#generate_json/1","title":"FastPostmanCollection.generate_json/1","type":"function"},{"doc":"","ref":"FastPostmanCollection.Collect.html","title":"FastPostmanCollection.Collect","type":"module"},{"doc":"","ref":"FastPostmanCollection.Collect.html#collect_documentation/2","title":"FastPostmanCollection.Collect.collect_documentation/2","type":"function"},{"doc":"","ref":"FastPostmanCollection.Collect.html#generate_data_by_router/1","title":"FastPostmanCollection.Collect.generate_data_by_router/1","type":"function"},{"doc":"","ref":"FastPostmanCollection.CollectDataItem.html","title":"FastPostmanCollection.CollectDataItem","type":"module"},{"doc":"","ref":"FastPostmanCollection.CollectDataItemParams.html","title":"FastPostmanCollection.CollectDataItemParams","type":"module"},{"doc":"","ref":"FastPostmanCollection.CollectDataItemParams.html#get_from_map/1","title":"FastPostmanCollection.CollectDataItemParams.get_from_map/1","type":"function"},{"doc":"","ref":"FastPostmanCollection.CollectDataModule.html","title":"FastPostmanCollection.CollectDataModule","type":"module"},{"doc":"","ref":"FastPostmanCollection.CollectDataModuleParams.html","title":"FastPostmanCollection.CollectDataModuleParams","type":"module"},{"doc":"","ref":"FastPostmanCollection.CollectDataModuleParams.html#get_from_map/1","title":"FastPostmanCollection.CollectDataModuleParams.get_from_map/1","type":"function"},{"doc":"","ref":"FastPostmanCollection.Config.html","title":"FastPostmanCollection.Config","type":"module"},{"doc":"","ref":"FastPostmanCollection.Config.html#get_file_path_to_generate/0","title":"FastPostmanCollection.Config.get_file_path_to_generate/0","type":"function"},{"doc":"","ref":"FastPostmanCollection.Config.html#get_name_collection/0","title":"FastPostmanCollection.Config.get_name_collection/0","type":"function"},{"doc":"","ref":"FastPostmanCollection.Config.html#get_pipe_tokens/0","title":"FastPostmanCollection.Config.get_pipe_tokens/0","type":"function"},{"doc":"","ref":"FastPostmanCollection.Config.html#get_variables/0","title":"FastPostmanCollection.Config.get_variables/0","type":"function"},{"doc":"","ref":"FastPostmanCollection.GenerateCollection.html","title":"FastPostmanCollection.GenerateCollection","type":"module"},{"doc":"","ref":"FastPostmanCollection.GenerateCollection.html#generate/2","title":"FastPostmanCollection.GenerateCollection.generate/2","type":"function"},{"doc":"","ref":"FastPostmanCollection.GenerateCollection.html#generate_to_json/2","title":"FastPostmanCollection.GenerateCollection.generate_to_json/2","type":"function"},{"doc":"","ref":"FastPostmanCollection.GenerateCollection.html#parse_collect_data_item/1","title":"FastPostmanCollection.GenerateCollection.parse_collect_data_item/1","type":"function"},{"doc":"","ref":"FastPostmanCollection.GenerateCollection.html#parse_collect_data_module/1","title":"FastPostmanCollection.GenerateCollection.parse_collect_data_module/1","type":"function"},{"doc":"","ref":"FastPostmanCollection.GenerateCollection.Structs.Auth.html","title":"FastPostmanCollection.GenerateCollection.Structs.Auth","type":"module"},{"doc":"","ref":"FastPostmanCollection.GenerateCollection.Structs.Auth.html#generate/1","title":"FastPostmanCollection.GenerateCollection.Structs.Auth.generate/1","type":"function"},{"doc":"","ref":"FastPostmanCollection.GenerateCollection.Structs.Auth.html#get_config_auth_pipe/1","title":"FastPostmanCollection.GenerateCollection.Structs.Auth.get_config_auth_pipe/1","type":"function"},{"doc":"","ref":"FastPostmanCollection.GenerateCollection.Structs.Auth.html#get_variables_tokens/0","title":"FastPostmanCollection.GenerateCollection.Structs.Auth.get_variables_tokens/0","type":"function"},{"doc":"","ref":"FastPostmanCollection.GenerateCollection.Structs.Body.html","title":"FastPostmanCollection.GenerateCollection.Structs.Body","type":"module"},{"doc":"","ref":"FastPostmanCollection.GenerateCollection.Structs.Body.html#generate/1","title":"FastPostmanCollection.GenerateCollection.Structs.Body.generate/1","type":"function"},{"doc":"","ref":"FastPostmanCollection.GenerateCollection.Structs.Body.html#has_body?/1","title":"FastPostmanCollection.GenerateCollection.Structs.Body.has_body?/1","type":"function"},{"doc":"","ref":"FastPostmanCollection.GenerateCollection.Structs.Body.html#is_disabled/1","title":"FastPostmanCollection.GenerateCollection.Structs.Body.is_disabled/1","type":"function"},{"doc":"","ref":"FastPostmanCollection.GenerateCollection.Structs.Event.html","title":"FastPostmanCollection.GenerateCollection.Structs.Event","type":"module"},{"doc":"","ref":"FastPostmanCollection.GenerateCollection.Structs.Event.html#generate/1","title":"FastPostmanCollection.GenerateCollection.Structs.Event.generate/1","type":"function"},{"doc":"","ref":"FastPostmanCollection.GenerateCollection.Structs.Event.html#generate_auth_pre_request/1","title":"FastPostmanCollection.GenerateCollection.Structs.Event.generate_auth_pre_request/1","type":"function"},{"doc":"","ref":"FastPostmanCollection.GenerateCollection.Structs.Folder.html","title":"FastPostmanCollection.GenerateCollection.Structs.Folder","type":"module"},{"doc":"","ref":"FastPostmanCollection.GenerateCollection.Structs.Formdata.html","title":"FastPostmanCollection.GenerateCollection.Structs.Formdata","type":"module"},{"doc":"","ref":"FastPostmanCollection.GenerateCollection.Structs.Info.html","title":"FastPostmanCollection.GenerateCollection.Structs.Info","type":"module"},{"doc":"","ref":"FastPostmanCollection.GenerateCollection.Structs.Item.html","title":"FastPostmanCollection.GenerateCollection.Structs.Item","type":"module"},{"doc":"","ref":"FastPostmanCollection.GenerateCollection.Structs.Main.html","title":"FastPostmanCollection.GenerateCollection.Structs.Main","type":"module"},{"doc":"","ref":"FastPostmanCollection.GenerateCollection.Structs.Query.html","title":"FastPostmanCollection.GenerateCollection.Structs.Query","type":"module"},{"doc":"","ref":"FastPostmanCollection.GenerateCollection.Structs.Query.html#generate/1","title":"FastPostmanCollection.GenerateCollection.Structs.Query.generate/1","type":"function"},{"doc":"","ref":"FastPostmanCollection.GenerateCollection.Structs.Request.html","title":"FastPostmanCollection.GenerateCollection.Structs.Request","type":"module"},{"doc":"","ref":"FastPostmanCollection.GenerateCollection.Structs.Url.html","title":"FastPostmanCollection.GenerateCollection.Structs.Url","type":"module"},{"doc":"","ref":"FastPostmanCollection.GenerateCollection.Structs.Url.html#generate/1","title":"FastPostmanCollection.GenerateCollection.Structs.Url.generate/1","type":"function"},{"doc":"","ref":"FastPostmanCollection.GenerateCollection.Structs.Variable.html","title":"FastPostmanCollection.GenerateCollection.Structs.Variable","type":"module"},{"doc":"","ref":"FastPostmanCollection.Helpers.Map.html","title":"FastPostmanCollection.Helpers.Map","type":"module"},{"doc":"","ref":"FastPostmanCollection.Helpers.Map.html#map_from_struct_recursive/1","title":"FastPostmanCollection.Helpers.Map.map_from_struct_recursive/1","type":"function"},{"doc":"","ref":"FastPostmanCollection.Helpers.Map.html#prepare_folder/1","title":"FastPostmanCollection.Helpers.Map.prepare_folder/1","type":"function"},{"doc":"","ref":"FastPostmanCollection.Helpers.Map.html#to_keyword_list/1","title":"FastPostmanCollection.Helpers.Map.to_keyword_list/1","type":"function"},{"doc":"","ref":"FastPostmanCollection.Helpers.RouterInfo.html","title":"FastPostmanCollection.Helpers.RouterInfo","type":"module"},{"doc":"","ref":"FastPostmanCollection.Helpers.RouterInfo.html#route_info/4","title":"FastPostmanCollection.Helpers.RouterInfo.route_info/4","type":"function"},{"doc":"GENERATE POSTMAN COLECTIONS","ref":"Mix.Tasks.Fs.GetCollection.html","title":"mix fs.get_collection","type":"task"},{"doc":"","ref":"FastPostmanCollection.Expectation.GiveTokenAuth.html","title":"FastPostmanCollection.Expectation.GiveTokenAuth","type":"exception"},{"doc":"","ref":"FastPostmanCollection.Expectation.PhoenixRouterNotFound.html","title":"FastPostmanCollection.Expectation.PhoenixRouterNotFound","type":"exception"},{"doc":"# FastPostmanCollection\n\nThis library helps you generate a Postman collection from your Phoenix router (`MyApp.Router`).\nYou can document your endpoints using `@doc` annotations for **params, body, form data**, and more.\nPipelines (plugs) can also be auto-scanned and added to the collection automatically.\n\nExample generated collection:\n\n![collection](assets/collection.png)\n\nThis library uses the official Postman schema: https://schema.postman.com/","ref":"readme.html","title":"FastPostmanCollection","type":"extras"},{"doc":"- [Installation](#installation)\n- [Description and Titles](#description-and-title-of-collection)\n- [Query Parameters](#params-in-your-collection)\n- [Body Parameters](#body-parameters)\n- [Form Data](#formdata-options)\n- [Authentication Tokens](#how-to-auto-scan-and-autoput-your-pipes-token)\n- [Organizing Folders](#organizing-folders-in-the-collection)\n- [Mix Commands](#mix-commands)\n- [Todo](#todo)\n- [Feedback](#you-like-the-idea)\n- [Changelog](#changelog)","ref":"readme.html#table-of-contents","title":"Table of Contents - FastPostmanCollection","type":"extras"},{"doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `fast_postman_collection` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:fast_postman_collection, \"~> 0.1.8\"}\n  ]\nend\n```\n\nConfigure fast_postman_collection\n\n- router -> your Phoenix router module *(required)*\n- pipe_tokens -> put in your auth bearer (`pipe_tokens`: a list of pipeline plugs (like `:admin_auth`) that should automatically add a Bearer token in the Postman request headers.)\n- variables -> variables to include in the Postman collection *(optional)*\n- file_path_collection -> path to save the generated collection *(optional)*\n\n```elixir\nconfig(:fast_postman_collection,\n  pipe_tokens: [:admin_auth, :user_auth],\n  name_collection: \"My collection\",\n  router: MyApp.Router,\n  variables: [\n    %{\n      key: \"host\",\n      value: \"http://localhost:4000\"\n    }\n  ]\n)\n```\n\nWhen you add router to your configuration, it will be able to generate a collection _using the command_ - `mix fs.get_collection`","ref":"readme.html#installation","title":"Installation - FastPostmanCollection","type":"extras"},{"doc":"![naming](assets/naming.png)\n\n```elixir\n@moduledoc \"\"\"\n# Post Controller\nThis will be used as the folder name in the generated Postman collection.\n\"\"\"\n\n@doc \"\"\"\n# Create Post\nThis will be used as the request title in the Postman collection.\n\nUse this endpoint to create a new post.\nAll content inside this doc block will be added to the request description in the collection.\n\"\"\"\n```\n\nIf you don't provide a `@doc` annotation, the default name will be taken from the module or function name.","ref":"readme.html#description-and-title-of-collection","title":"Description and Title of collection - FastPostmanCollection","type":"extras"},{"doc":"These parameters will be included in the URL as query strings.\nFor example, the generated URL might look like: ?limit=0&page=1\n\n```elixir\n@doc params: %{\n  limit: 0,\n  page: %{\n    key: \"page\",\n    value: 1,\n    description: \"Page number for pagination\"\n  }\n}\ndef index(conn, params) do\n  json(conn, params)\nend\n```\n\n![params](assets/params.png)","ref":"readme.html#params-in-your-collection","title":"Params in Your Collection - FastPostmanCollection","type":"extras"},{"doc":"These parameters will be included in the request body.\nBy default, the body is sent in JSON format.\n\nThis is how you define a request body in JSON format:\n\n```elixir\n@doc \"\"\"\n# Create post\n\"\"\"\n@doc body: %{\n        post: %{\n          title: \"\"\n        }\n      }\ndef create_post(conn, params) do\n  json(conn, params)\nend\n```\n\n![body](assets/body.png)","ref":"readme.html#body-parameters","title":"Body Parameters - FastPostmanCollection","type":"extras"},{"doc":"To send form data (e.g. file uploads):\n\n```elixir\n@doc mode: \"formdata\"\n@doc formdata: [\n        %{\n          key: \"image\",\n          value: nil,\n          type: \"file\"\n        }\n      ]\n```","ref":"readme.html#formdata-options","title":"Formdata options - FastPostmanCollection","type":"extras"},{"doc":"How to auto scan and autoput your pipe's token","ref":"readme.html#how-to-auto-scan-and-apply-authentication-tokens","title":"How to Auto-Scan and Apply Authentication Tokens - FastPostmanCollection","type":"extras"},{"doc":"router.ex\n\n```elixir\nscope \"/user\" do\n  pipe_through(:admin_auth)\n  get(\"/\", UserController, :index)\nend\n```\n\nconfig.exs\n\n```elixir\nconfig(:fast_postman_collection,\n  pipe_tokens: [:admin_auth, :user_auth]\n```\n\nAll tokens puts and scans from your pipelines\n\n![token](assets/token.png)","ref":"readme.html#example","title":"Example - FastPostmanCollection","type":"extras"},{"doc":"You can also automatically insert tokens into variables from a response:\n\n```elixir\n @doc auth_pre_request: %{is_enabled: true, from_resp_token: \"token\", variable_token: \"admin_variable\"}\n```","ref":"readme.html#extract-token-from-response-automatically","title":"Extract Token from Response Automatically - FastPostmanCollection","type":"extras"},{"doc":"You can use @moduledoc folder_path: \"Admin\" to place your module's requests inside a specific folder in the Postman collection.\n\nThe final folder structure will look like:\nAdmin / UserController\n\n#### Example\n\n```elixir\ndefmodule MyAppWeb.AdminUserController do\n  use MyAppWeb, :controller\n  @moduledoc folder_path: \"Admin\"\n  # this module puts to /admin/user controller\n  @moduledoc \"\"\"\n  # user controller\n  \"\"\"\n\nend\n```","ref":"readme.html#organizing-folders-in-the-collection","title":"Organizing Folders in the Collection - FastPostmanCollection","type":"extras"},{"doc":"- mix fs.get_collection: _This command generate in your directory file with collection_","ref":"readme.html#mix-commands","title":"Mix commands - FastPostmanCollection","type":"extras"},{"doc":"- [ ] filtering in mix fs.get_collection","ref":"readme.html#todo","title":"Todo - FastPostmanCollection","type":"extras"},{"doc":"If you like the idea of the library, write in this \"issue\" on github and I will add this functionality as soon as I have free time.","ref":"readme.html#you-like-the-idea","title":"You like the idea? - FastPostmanCollection","type":"extras"},{"doc":"- 0.1.8: Exclude null entries in Request Header, fix for full paragraph and update documentation for library\n- 0.1.7: Added support for including endpoint descriptions in Postman collections\n- 0.1.6: Previous version","ref":"readme.html#changelog","title":"Changelog - FastPostmanCollection","type":"extras"}],"producer":{"name":"ex_doc","version":[48,46,51,50,46,49]}}